:
# NAME:
#	scm-funcs.sh - scm wrapper funcs
#

# RCSid:
#	$Id: scm-funcs.sh,v 1.6 2021/02/13 17:48:25 sjg Exp $
#
#	@(#) Copyright (c) 2020 Simon J. Gerraty
#
#	This file is provided in the hope that it will
#	be of use.  There is absolutely NO WARRANTY.
#	Permission to copy, redistribute or otherwise
#	use this file is hereby granted provided that 
#	the above copyright notice and this notice are
#	left intact. 
#      
#	Please send copies of changes and bug-fixes to:
#	sjg@crufty.net
#

get_SCM() {
    for d in . ${SB_SRC:-$SB/src} $SB ...
    do
        for clue in CVS/Entries .hg .svn .git 
        do
            case "$d" in
            ...)
                if type find_it > /dev/null 2>&1; then
                    x=`find_it --start .. $clue`
                    test -s $x/$clue || continue
                    d=$x
                fi
                ;;
            esac
            test -s $d/$clue || continue
            case "$clue" in
            CVS/*) echo cvs; return;;
            .*) echo ${clue#.}; return;;
            esac
        done
    done
}

SCM=${SB_SCM:-${SCM:-`get_SCM`}}
SCM_VAR=`echo $SCM | tr '[a-z]' '[A-Z]'`
eval SCM_CMD=\${$SCM_VAR:-$SCM}
PAGER=${PAGER:-more}

scm_op() {
    $SCM_CMD "$@" | ${PAGER}
}

scm_ops() {
    op=$1; shift
    for f in "$@"
    do
        scm_op $op $f || break
    done
}

scm_diff() {
    case "$1" in
    --xargs) _xargs=xargs; shift;;
    *) _xargs=;;
    esac
    diff_opts=
    case "$SCM" in
    cvs) diff_opts="-up";;
    git) diff_opts="--full-index";;
    svn) diff_opts="-x -p";;
    esac
    $_xargs $SCM_CMD diff $diff_opts $opt_x "$@"
}

diff2list() {
    # do not assume SCM that generated patch
    sed -n \
    -e '/^diff.*--git/s,.* b/,,p' \
    -e '/^Index:/s,Index: ,,p' \
    -e '/^Property changes on:/s,Property changes on: ,,p' \
    "$@" | sort -u
}

case "$SCM" in
git|hg) ;;
*)
    eval "${SCM}_diff() { scm_diff \"\$@\" | ${PAGER}; }"
    for op in help
    do
        eval "${SCM}_$op() { scm_op $op \"\$@\"; }"
    done
    for op in log
    do
        eval "${SCM}_$op() { scm_op $op \"\$@\"; }"
        eval "${SCM}_${op}s() { scm_ops $op \"\$@\"; }"
    done
    ;;
esac

    
